hstrat.hstrat.HereditaryStratumOrderedStoreList
===============================================

.. currentmodule:: hstrat.hstrat

.. autoclass:: HereditaryStratumOrderedStoreList

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~HereditaryStratumOrderedStoreList.Clone
      ~HereditaryStratumOrderedStoreList.DelRanks
      ~HereditaryStratumOrderedStoreList.DepositStratum
      ~HereditaryStratumOrderedStoreList.GetColumnIndexOfRank
      ~HereditaryStratumOrderedStoreList.GetNumStrataRetained
      ~HereditaryStratumOrderedStoreList.GetRankAtColumnIndex
      ~HereditaryStratumOrderedStoreList.GetRetainedRanks
      ~HereditaryStratumOrderedStoreList.GetStratumAtColumnIndex
      ~HereditaryStratumOrderedStoreList.IterRankDifferentia
      ~HereditaryStratumOrderedStoreList.__init__
   
   

   
   
   